#
# spec file for package grim
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           grim
Version:        1.4.1
Release:        1.4.1%{?dist}
Summary:        Wayland compositor image grabber
License:        MIT
Group:          Productivity/Graphics/Other
URL:            https://git.sr.ht/~emersion/grim
Source:         https://git.sr.ht/~emersion/grim/refs/download/v%{version}/grim-%{version}.tar.gz
BuildRequires:  gcc
BuildRequires:  meson >= 0.59.0
#BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(scdoc)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(pixman-1)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-protocols) >= 1.14
Recommends:     slurp

%description
This tool can grab images from a Wayland compositor.

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}
%{_mandir}/man?/%{name}*

%changelog
* Fri Jun 23 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.4.1:
  * render: print error message when image alloc fails
  * write_jpg: fix printf format specifier
  * Fail when more than one arguments are passed in
- Drop 0001-write_jpg-fix-printf-format-specifier.patch
* Mon Feb 28 2022 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream change:
  * 0001-write_jpg-fix-printf-format-specifier.patch
* Fri Feb 11 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.4.0:
  * Read XDG_PICTURES_DIR from user-dirs.dirs file
  * add bash completion
  * render: use pixman to compose output buffers
  * render: use convolution filter when downscaling
  * Allow setting compression level for PNG output
  * write_png: fix out of bounds read
  * render: add support for ≤ 24bpp pixel formats
  * Use alternate Wayland to Pixman format conversion on big-endian
  * Rename cairo_{jpg,ppm} to write_{jpg,ppm}
  * Use stream-type functions to save images
  * Remove cairo dependency
  * man: fix wrong section headers
  * Add example for taking screenshot of active window
  * Make get_output_dir return value const
  * Replace sprintf with snprintf
  * Make output_filename const
  * Stop using PATH_MAX
* Mon Apr 19 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.3.2:
  * Remove unnecessary wl_display_dispatch calls
  * Fix 180-degree rotated buffers without Y_INVERT
  * main,render: replace assert(false) with abort().
* Wed Jul 22 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.3.1:
  * Explain that '.' is grim's final fallback dir
  * Correct interpretation of output rotation
  * Fix maybe-uninitialized warning
  * Add completions for fish-shell
  * completions: add missing option
  * Improve error message for when supplied region is invalid
  * fix bufferoverflow in output_filepath
  * contrib/completions: fix fish file path
  * contrib/completions: fix unset datadir variable
* Thu Jan 16 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.3.0:
  * Allow to be invoked without a destination file argument.
    In which case a timestamped file will be written in
    $XDG_PICTURES_DIR.
  * Allow user to set default output dir.
  * Provide more helpful error message
  * Fix maybe-uninitialized warning
* Tue Jun  4 2019 mvetter@suse.com
- Update to 1.2.0:
  * Add support for the PPM format. This is useful for speeding up
    grim when piping its output into another process.
* Wed Feb  6 2019 mvetter@suse.com
- Update to 1.1:
  * Add an option to disable JPEG support at build-time
  * Add support for the WL_SHM_FORMAT_ABGR8888 format
  * Add various examples to README
* Tue Feb  5 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in descriptions.
* Fri Jan 25 2019 mvetter@suse.com
- Package grim 1.0 for openSUSE
